@@ -5,12 +5,10 @@ from collections import OrderedDict
 from copy import deepcopy
 import json
 
-from numpy import arcsin, array, cos, inf, isfinite, nan, sin, sqrt
-import scipy.special
-
 from asteval import Interpreter, get_ast_names, valid_symbol_name
-
-from . import uncertainties
+from numpy import arcsin, array, cos, inf, nan, sin, sqrt
+import scipy.special
+import uncertainties
 
 SCIPY_FUNCTIONS = {'gamfcn': scipy.special.gamma}
 for name in ('erf', 'erfc', 'wofz'):
@@ -43,18 +41,9 @@ def isclose(x, y, rtol=1e-5, atol=1e-8):
         True if `x` and `y` are the same within tolerance, otherwise False.
 
     """
-    def within_tol(x, y, atol, rtol):
-        return abs(x - y) <= atol + rtol * abs(y)
-
-    xfin = isfinite(x)
-    yfin = isfinite(y)
-
-    # both are finite
-    if xfin and yfin:
-        return within_tol(x, y, atol, rtol)
-    elif x == y:
-        return True
-    return False
+    if x in (-inf, inf, nan) or y in (-inf, inf, nan):
+        return (x == y)
+    return (abs(x - y) <= atol + rtol * abs(y))
 
 
 class Parameters(OrderedDict):
@@ -766,7 +755,7 @@ class Parameter(object):
         # If you just assign to self._val then
         # _expr_eval.symtable[self.name]
         # becomes stale if parameter.expr is not None.
-        if (isinstance(self._val, uncertainties.Variable) and
+        if (isinstance(self._val, uncertainties.core.Variable) and
                 self._val is not nan):
 
             try:
